@@ -13,7 +13,7 @@ use namespace::autoclean;
 
 extends 'App::Sqitch::Engine';
 
-our $VERSION = '0.934';
+our $VERSION = '0.935';
 
 has client => (
     is       => 'ro',
@@ -24,7 +24,7 @@ has client => (
         my $sqitch = shift->sqitch;
         $sqitch->db_client
             || $sqitch->config->get( key => 'core.pg.client' )
-            || 'psql' . ( $^O eq 'Win32' ? '.exe' : '' );
+            || 'psql' . ( $^O eq 'MSWin32' ? '.exe' : '' );
     },
 );
 
